[PATCH 0/2] drop unaligned loads
- From
Jeff King <peff@peff.net>
- Date
- Sep 24, 2020, 19:16 UTC
- Message-ID
- <20200924191638.GA2528003@coredump.intra.peff.net>
On Thu, Sep 24, 2020 at 10:22:20AM -0700, Junio C Hamano wrote:
Show 19 quoted lines
> Jeff King <peff@peff.net> writes: > > > Then I did the same, but building with -DNO_UNALIGNED_LOADS. The latter > > actually ran faster, by a small margin. Here are the hyperfine results: > > > > [stock] > > Time (mean ± σ): 6.638 s ± 0.081 s [User: 6.269 s, System: 0.368 s] > > Range (min … max): 6.550 s … 6.841 s 10 runs > > > > [-DNO_UNALIGNED_LOADS] > > Time (mean ± σ): 6.418 s ± 0.015 s [User: 6.058 s, System: 0.360 s] > > Range (min … max): 6.394 s … 6.447 s 10 runs > > > > For casual use as in reftables I doubt the difference is even > > measurable. But this result implies that perhaps we ought to just be > > using the fallback version all the time. > > I like that one. One less configurable knob that makes us execute > different codepaths is one less thing to be worried about.
Here it is with a little more research, then, and a cleanup we can do on top.
[1/2]: bswap.h: drop unaligned loads [2/2]: Revert "fast-export: use local array to store anonymized oid"
Makefile | 1 - builtin/fast-export.c | 8 ++++---- compat/bswap.h | 24 ------------------------ 3 files changed, 4 insertions(+), 29 deletions(-)
-Peff